# Utils Package

This repo contains some useful helper function for Python

### Installation

Install this package using

```
pip install utils-package-Martin36
```

To use this package you will need to download the nltk stopwords package. This is done by running:

```
nltk.download("stopwords")
```



